#!/bin/bash

case "$1" in
  -d|--durable)
    mode="durable"
    ;; 
  -r|--reliable)
    mode="reliable"
    ;; 
  -q|--queue)
    mode="queue"
    ;; 
*)
  echo $"Usage $0 [-d|--durable|-r|--reliable|-q|--queue]"
  exit 1
esac

# Remove the durable or reliable argument, so we can pass the rest to mule.
shift

if [ -z $MULE_HOME ]; then
  if [ -d ../mule-1.4.3 ]; then
    curdir=`pwd`
    parentdir=`dirname $curdir`
    MULE_HOME=$parentdir/mule-1.4.3
    export MULE_HOME
  fi
fi

if [ ! -d $MULE_HOME ]; then
  echo "MULE_HOME must be set to the Mule Home Directory before running this program.  Exiting."
  exit 1
fi

# If MULE_BASE is not set, make it MULE_HOME
if [ -z "$MULE_BASE" ] ; then
  MULE_BASE="$MULE_HOME"
  export MULE_BASE
fi

# Any changes to the files in ./conf will take precedence over those deployed to $MULE_HOME/lib/user
MULE_LIB=./conf
export MULE_LIB


echo "MULE_HOME: $MULE_HOME"

echo "Run the Mule echo with mode: $mode"

configFile=."/conf/echo-config-$mode.xml"
if [ ! -f $configFile ]; then
  echo "Error: Mule configuration file is missing, file: $configFile"
  exit 1
fi

#exec "$MULE_BASE/bin/mule" -config ./conf/echo-config-durable.xml -debug

echo exec "$MULE_BASE/bin/mule" -config ./conf/echo-config-$mode.xml $*

exec "$MULE_BASE/bin/mule" -config ./conf/echo-config-$mode.xml $*

